@@ -1,6 +1,6 @@
 __all__ = ['selenium', 'paramiko', 'telegram', 'dropbox', 'util', 'schedule']
 
-__version__ = '0.6.4'
+__version__ = '0.6.13'
 
 from . import selenium, paramiko, telegram, dropbox, util, schedule
 
@@ -25,7 +25,7 @@ def update_scode() -> None:
     import os
     import subprocess
     os.environ['PATH'] = ';'.join(distinct(os.getenv('PATH').split(';') if os.getenv('PATH') else [] + ["C:\\Python38\\Scripts\\", "C:\\Python38\\", "C:\\Python34\\Scripts\\", "C:\\Python34\\"]))
-    subprocess.run(['python', '-m', 'pip', 'install', '-U', 'scode'])
+    subprocess.run(['python', '-m', 'pip', 'install', '-U', 'scode'], stdout=subprocess.DEVNULL)
 
 
 def refresh() -> None:
