@@ -1,4 +1,11 @@
 def dropbox_upload_file(src_file_path, destination_path, ACCESS_TOKEN):
+    """
+    It takes a file path, uploads it to Dropbox, and returns the file path of the uploaded file
+    
+    :param src_file_path: The path to the file you want to upload
+    :param destination_path: The path to the folder where you want to upload the file
+    :param ACCESS_TOKEN: The access token you got from the Dropbox API console
+    """
     import dropbox
     dbx = dropbox.Dropbox(ACCESS_TOKEN)
     destination_path = destination_path.replace('\\', '/')
@@ -11,6 +18,14 @@ def dropbox_upload_file(src_file_path, destination_path, ACCESS_TOKEN):
         dbx.files_upload(f.read(), destination_path, mode=dropbox.files.WriteMode.overwrite)
 
 def dropbox_upload_folder(folder_path, destination_path, ACCESS_TOKEN):
+    """
+    It takes a folder path, a destination path, and an access token, and uploads the folder to the
+    destination path on Dropbox
+    
+    :param folder_path: The path to the folder you want to upload
+    :param destination_path: The path to the folder in Dropbox where you want to upload the file
+    :param ACCESS_TOKEN: The access token for your Dropbox account
+    """
     import os
     import glob
     folder_path = folder_path.replace('\\', '/')
