@@ -198,210 +198,231 @@ def load_cache_driver(userId, chrome_options = None, **kwargs):
     return load_driver(chrome_options=chrome_options, mode=['cache'], userId=userId, **kwargs)
 
 
-def n_login(driver: WebDriver, nid: str, pwd: str, keep_login: bool=True, ip_safe: bool=False, force: bool=False, mobile: bool=False):
+def n_login(driver: WebDriver, nid: str, pwd: str, keep_login: bool=True, ip_safe: bool=False, force: bool=False, mobile: bool=False, as_tuple: tuple=False):
     """
-    It logs in to Naver.com and returns True if it was successful, False if it was not, and a string if
+    It logs in to Naver.com and returns True if it was successful, False if it wasn't, and a string if
     there was a problem
     
     :param driver: WebDriver
     :type driver: WebDriver
-    :param nid: your naver id
+    :param nid: Naver ID
     :type nid: str
     :param pwd: str
     :type pwd: str
     :param keep_login: If True, the account will be kept logged in. If False, the account will be logged
     out after closing the browser, defaults to True
     :type keep_login: bool (optional)
-    :param ip_safe: If True, it will use the IP Safe feature, defaults to False
+    :param ip_safe: If True, the login will be done with IP Safe, defaults to False
     :type ip_safe: bool (optional)
-    :param force: If True, it will force the login process, defaults to False
+    :param force: If True, it will try to login even if it's already logged in, defaults to False
     :type force: bool (optional)
     :param mobile: bool=False, defaults to False
     :type mobile: bool (optional)
-    :return: a boolean value.
+    :param as_tuple: If True, returns a tuple of (bool, str), defaults to False
+    :type as_tuple: tuple (optional)
+    :return: A tuple of two values.
     """
     
-    if mobile:
-        
-        if force:
-            pass
-        else:
-            
-            try:
-                driver.get('https://m.naver.com/aside/')
-            except TimeoutException:
-                try:
-                    driver.refresh()
-                except TimeoutException:
-                    sys.stdout.write('네트워크 문제로 로그인 되어있는지 확인이 불가합니다.\n')
-                    return False
-            except Exception as e:
-                sys.stdout.write(f'{e}\n')
-                return False
-            
-            time.sleep(.5)
-            
-            try:
-                if driver.find_element(By.CSS_SELECTOR, '.MM_LOGINOUT').text == '로그아웃':
-                    return True
-            except:
-                pass
-        
-        driver.header_overrides = {'Referer': 'http://m.naver.com/aside/'}
-        driver.get('https://nid.naver.com/nidlogin.login?svctype=262144&amp;url=http://m.naver.com/aside/')
-
-        origin_clip = pyperclip.paste()
-        try:
-            pyperclip.copy(nid)
-            driver.find_elements(By.CSS_SELECTOR, '#id')[0].send_keys(Keys.CONTROL, 'v')
-            time.sleep(0.5)
-
-            pyperclip.copy(pwd)
-            driver.find_elements(By.CSS_SELECTOR, '#pw')[0].send_keys(Keys.CONTROL, 'v')
-        finally:
-            pyperclip.copy(origin_clip)
-
-        if keep_login:
-            if driver.find_element(By.CSS_SELECTOR, 'input#stay').get_attribute('value').lower() == 'off':
-                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#stay'))
-        else:
-            if driver.find_element(By.CSS_SELECTOR, 'input#stay').get_attribute('value').lower() == 'on':
-                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#stay'))
-
-        driver.find_elements(By.CSS_SELECTOR, 'button[class="btn_check"]')[0].click()
-        time.sleep(1)
+    flag = None
     
-    else:
+    try:
         
-        if force:
-            pass
-        else:
-            try:
-                driver.get('https://www.naver.com')
-            except TimeoutException:
+        if mobile:
+            
+            if force:
+                pass
+            else:
+                
                 try:
-                    driver.refresh()
+                    driver.get('https://m.naver.com/aside/')
                 except TimeoutException:
-                    sys.stdout.write('네트워크 문제로 로그인 되어있는지 확인이 불가합니다.\n')
-                    return False
-            except Exception as e:
-                sys.stdout.write(f'{e}\n')
-                return False
-            time.sleep(.5)
+                    try:
+                        driver.refresh()
+                    except TimeoutException:
+                        sys.stdout.write('네트워크 문제로 로그인 되어있는지 확인이 불가합니다.\n')
+                        flag = "네트워크 문제"
+                        return
+                except Exception as e:
+                    sys.stdout.write(f'{e}\n')
+                    flag = ' '.join(str(e).splitlines())
+                    return
+                
+                time.sleep(.5)
+                
+                try:
+                    if driver.find_element(By.CSS_SELECTOR, '.MM_LOGINOUT').text == '로그아웃':
+                        flag = True
+                        return
+                except:
+                    pass
+            
+            driver.header_overrides = {'Referer': 'http://m.naver.com/aside/'}
+            driver.get('https://nid.naver.com/nidlogin.login?svctype=262144&amp;url=http://m.naver.com/aside/')
+
+            origin_clip = pyperclip.paste()
             try:
-                logout_iframe = driver.find_element(By.CSS_SELECTOR, 'iframe#minime')
-                driver.switch_to.frame(logout_iframe)
-                driver.find_element(By.CSS_SELECTOR, 'a.btn_logout')
-            except:
+                pyperclip.copy(nid)
+                driver.find_elements(By.CSS_SELECTOR, '#id')[0].send_keys(Keys.CONTROL, 'v')
+                time.sleep(0.5)
+
+                pyperclip.copy(pwd)
+                driver.find_elements(By.CSS_SELECTOR, '#pw')[0].send_keys(Keys.CONTROL, 'v')
+            finally:
+                pyperclip.copy(origin_clip)
+
+            if keep_login:
+                if driver.find_element(By.CSS_SELECTOR, 'input#stay').get_attribute('value').lower() == 'off':
+                    driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#stay'))
+            else:
+                if driver.find_element(By.CSS_SELECTOR, 'input#stay').get_attribute('value').lower() == 'on':
+                    driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#stay'))
+
+            driver.find_elements(By.CSS_SELECTOR, 'button[class="btn_check"]')[0].click()
+            time.sleep(1)
+        
+        else:
+            
+            if force:
                 pass
             else:
                 try:
-                    sys.stdout.write(f'''{driver.find_element(By.CSS_SELECTOR, 'div.email.MY_EMAIL').text.split('@')[0]} : 이미 로그인 되어있습니다.\n''')
+                    driver.get('https://www.naver.com')
+                except TimeoutException:
+                    try:
+                        driver.refresh()
+                    except TimeoutException:
+                        sys.stdout.write('네트워크 문제로 로그인 되어있는지 확인이 불가합니다.\n')
+                        flag = "네트워크 문제"
+                        return
+                except Exception as e:
+                    sys.stdout.write(f'{e}\n')
+                    flag = ' '.join(str(e).splitlines())
+                    return
+                time.sleep(.5)
+                try:
+                    logout_iframe = driver.find_element(By.CSS_SELECTOR, 'iframe#minime')
+                    driver.switch_to.frame(logout_iframe)
+                    driver.find_element(By.CSS_SELECTOR, 'a.btn_logout')
                 except:
                     pass
+                else:
+                    try:
+                        sys.stdout.write(f'''{driver.find_element(By.CSS_SELECTOR, 'div.email.MY_EMAIL').text.split('@')[0]} : 이미 로그인 되어있습니다.\n''')
+                    except:
+                        pass
+                    finally:
+                        flag = True
+                        return
                 finally:
-                    return True
-            finally:
-                driver.switch_to.default_content()
+                    driver.switch_to.default_content()
 
-        # driver.header_overrides = {'Referer': 'https://www.naver.com/', 'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.0.0 Safari/537.36'}
-        driver.header_overrides = {'Referer': 'https://www.naver.com/'}
-        driver.get('https://nid.naver.com/nidlogin.login?mode=form&url=https%3A%2F%2Fwww.naver.com')
-        
-        time.sleep(.5)
-
-        origin_clip = pyperclip.paste()
-        try:
-            pyperclip.copy(nid)
-            driver.find_element(By.CSS_SELECTOR, 'input#id').send_keys(Keys.CONTROL, 'v')
+            # driver.header_overrides = {'Referer': 'https://www.naver.com/', 'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.0.0 Safari/537.36'}
+            driver.header_overrides = {'Referer': 'https://www.naver.com/'}
+            driver.get('https://nid.naver.com/nidlogin.login?mode=form&url=https%3A%2F%2Fwww.naver.com')
+            
             time.sleep(.5)
-            pyperclip.copy(pwd)
-            driver.find_element(By.CSS_SELECTOR, 'input#pw').send_keys(Keys.CONTROL, 'v')
-        finally:
-            pyperclip.copy(origin_clip)
-        
-        if keep_login:
-            if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'off':
-                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
-        else:
-            if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'on':
-                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
 
-        time.sleep(1)
+            origin_clip = pyperclip.paste()
+            try:
+                pyperclip.copy(nid)
+                driver.find_element(By.CSS_SELECTOR, 'input#id').send_keys(Keys.CONTROL, 'v')
+                time.sleep(.5)
+                pyperclip.copy(pwd)
+                driver.find_element(By.CSS_SELECTOR, 'input#pw').send_keys(Keys.CONTROL, 'v')
+            finally:
+                pyperclip.copy(origin_clip)
+            
+            if keep_login:
+                if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'off':
+                    driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
+            else:
+                if driver.find_element(By.CSS_SELECTOR, 'input#keep').get_attribute('value').lower() == 'on':
+                    driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#keep'))
 
-        if ip_safe:
-            if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '-1':
-                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
-        else:
-            if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '1':
-                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
-        
-        time.sleep(1)
+            time.sleep(1)
+
+            if ip_safe:
+                if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '-1':
+                    driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
+            else:
+                if driver.find_element(By.CSS_SELECTOR, 'input#smart_LEVEL').get_attribute('value') == '1':
+                    driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'input#switch'))
+            
+            time.sleep(1)
+
+            # 로그인 버튼 클릭
+            try:
+                driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]').click()
+            except:
+                driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]'))
 
-        # 로그인 버튼 클릭
         try:
-            driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]').click()
+            WebDriverWait(driver, 2.5).until(expected_conditions.staleness_of(driver.find_element(By.TAG_NAME, 'html')))
         except:
-            driver.execute_script('arguments[0].click();', driver.find_element(By.CSS_SELECTOR, 'button[type="submit"][id="log.login"]'))
+            pass
+        try:
+            WebDriverWait(driver, 2.5).until(expected_conditions.presence_of_element_located((By.TAG_NAME, 'html')))
+        except:
+            pass
 
-    try:
-        WebDriverWait(driver, 2.5).until(expected_conditions.staleness_of(driver.find_element(By.TAG_NAME, 'html')))
-    except:
-        pass
-    try:
-        WebDriverWait(driver, 2.5).until(expected_conditions.presence_of_element_located((By.TAG_NAME, 'html')))
-    except:
-        pass
+        now_url = driver.current_url
+        source = driver.page_source
 
-    now_url = driver.current_url
-    source = driver.page_source
+        if 'https://m.naver.com/aside/' == now_url:
+            flag = True
+        
+        elif 'https://www.naver.com/' == now_url:
+            flag = True
+        
+        elif 'https://m.naver.com/' == now_url:
+            flag = True
+        
+        elif 'idRelease' in now_url and '대량생성' in source:
+            flag = '로그인제한(대량생성ID)'
 
-    flag = None
+        elif 'sleepId' in now_url and '회원님의 아이디는 휴면 상태로 전환되었습니다.' in source:
+            flag = '휴면'
+        
+        elif 'https://nid.naver.com/nidlogin.login' == now_url and '가입하지 않은 아이디이거나, 잘못된 비밀번호입니다.' in source:
+            flag = False
+        
+        elif 'https://nid.naver.com/nidlogin.login' == now_url and '스팸성 홍보활동' in source:
+            flag = '보호조치(스팸성 홍보활동)'
+        
+        elif 'idSafetyRelease' in now_url and '회원님의 아이디를 보호하고 있습니다.' in source and '개인정보보호 및 도용' in source:
+            flag = '보호조치(개인정보보호및도용)'
+        
+        elif 'idSafetyRelease' in now_url and '회원님의 아이디를 보호하고 있습니다.' in source and '타인으로 의심' in source:
+            flag = '보호조치(타인의심)'
+        
+        elif 'idSafetyRelease' in now_url and '회원님의 아이디를 보호하고 있습니다.' in source:
+            flag = '보호조치'
 
-    if 'https://m.naver.com/aside/' == now_url:
-        flag = True
-    
-    elif 'https://www.naver.com/' == now_url:
-        flag = True
-    
-    elif 'https://m.naver.com/' == now_url:
-        flag = True
-    
-    elif 'idRelease' in now_url and '대량생성' in source:
-        flag = '로그인제한(대량생성ID)'
+        elif 'https://nid.naver.com/user2/help/contactInfo?m=viewPhoneInfo' == now_url and '회원정보에 사용할 휴대 전화번호를 확인해 주세요.' in source:
+            flag = True
 
-    elif 'sleepId' in now_url and '회원님의 아이디는 휴면 상태로 전환되었습니다.' in source:
-        flag = '휴면'
-    
-    elif 'https://nid.naver.com/nidlogin.login' == now_url and '가입하지 않은 아이디이거나, 잘못된 비밀번호입니다.' in source:
-        flag = False
-    
-    elif 'https://nid.naver.com/nidlogin.login' == now_url and '스팸성 홍보활동' in source:
-        flag = '보호조치(스팸성 홍보활동)'
-    
-    elif 'idSafetyRelease' in now_url and '회원님의 아이디를 보호하고 있습니다.' in source and '개인정보보호 및 도용' in source:
-        flag = '보호조치(개인정보보호및도용)'
-    
-    elif 'idSafetyRelease' in now_url and '회원님의 아이디를 보호하고 있습니다.' in source and '타인으로 의심' in source:
-        flag = '보호조치(타인의심)'
-    
-    elif 'idSafetyRelease' in now_url and '회원님의 아이디를 보호하고 있습니다.' in source:
-        flag = '보호조치'
+        elif 'deviceConfirm' in now_url and '새로운 기기(브라우저) 로그인' in source:
+            flag = True
 
-    elif 'https://nid.naver.com/user2/help/contactInfo?m=viewPhoneInfo' == now_url and '회원정보에 사용할 휴대 전화번호를 확인해 주세요.' in source:
-        flag = True
-
-    elif 'deviceConfirm' in now_url and '새로운 기기(브라우저) 로그인' in source:
-        flag = True
-
-    else:
-        flag = False
-    
-    if flag is not True and flag is not False:
-        import requests
-        requests.get(f'http://aaa.e-e.kr/problemid/insert.php?id={nid}&desc={flag}')
-    
-    return flag
+        else:
+            flag = False
+        
+        if flag is not True and flag is not False:
+            import requests
+            requests.get(f'http://aaa.e-e.kr/problemid/insert.php?id={nid}&desc={flag}')
+    finally:
+        
+        if as_tuple:
+            if flag == True:
+                return True, "로그인 성공"
+            
+            elif isinstance(flag, str):
+                return False, flag
+            
+            else:
+                return False, "로그인 실패"
+        else:
+            return flag
 
 
 def daum_mail_login(driver, did, pwd):
@@ -798,24 +819,42 @@ def scrollDownUntilPageEnd(driver, SCROLL_PAUSE_SEC = 1):
 
 def solve_reCAPTCHA(driver: WebDriver):
     """
-    It takes a webdriver as an argument, finds the reCAPTCHA key and the current URL, and then uses the
-    anticaptcha API to solve the reCAPTCHA
+    It takes a Selenium WebDriver object as an argument, and returns True if it successfully solves the
+    reCAPTCHA on the current page, and False otherwise
     
     :param driver: WebDriver
     :type driver: WebDriver
-    :return: The return value is the result of the last expression in the function body, if any. If the
-    function doesn't have a return statement, the function returns None.
+    :return: A boolean value.
     """
     
     from anticaptchaofficial.recaptchav2proxyless import recaptchaV2Proxyless
+    from urllib.parse import urlsplit
 
     try:
         target_site_url = driver.current_url
         target_site_key = driver.execute_script('''return document.querySelector('[data-sitekey]').getAttribute('data-sitekey');''')
     except:
-        print('해당 사이트의 reCAPTCHA Key를 찾을 수 없습니다.')
-        return False
-
+        try:
+            driver.find_element(By.CSS_SELECTOR, 'iframe[src*="recaptcha"]')
+        except:
+            print('해당 사이트의 reCAPTCHA Key를 찾을 수 없습니다.')
+            return False
+        else:
+            try:
+                target_site_url = driver.current_url
+                target_site_key = dict([x.split('=') for x in urlsplit(driver.find_element(By.CSS_SELECTOR, 'iframe[src*="recaptcha"]').get_attribute('src')).query.split('&')])['k']
+            except:
+                try:
+                    print('해당 사이트의 reCAPTCHA Key를 찾을 수 없습니다.')
+                    return False
+                except:
+                    try:
+                        target_site_url = driver.current_url
+                        target_site_key = dict([x.split('=') for x in urlsplit(driver.find_element(By.CSS_SELECTOR, 'iframe[title="reCAPTCHA"]').get_attribute('src')).query.split('&')])['k']
+                    except:
+                        print('해당 사이트의 reCAPTCHA Key를 찾을 수 없습니다.')
+                        return False
+    
     API_KEY = 'b336be7de932b65c877403893a382713'
 
     solver = recaptchaV2Proxyless()
@@ -833,6 +872,15 @@ def solve_reCAPTCHA(driver: WebDriver):
     else:
         print("task finished with error "+solver.error_code)
     
-    result_flag = driver.execute_script(f'''document.getElementById("g-recaptcha-response").innerHTML = "{g_response}"''')
+    try:
+        driver.execute_script(f'''document.getElementById("g-recaptcha-response").innerHTML = "{g_response}"''')
+    except:
+        result_flag = False
+    else:
+        try:
+            tmp = driver.execute_script('return document.querySelector("#g-recaptcha-response").innerHTML;')
+        except:
+            tmp = None
+        result_flag = isinstance(tmp, str) and g_response == tmp.strip()
 
-    return result_flag == None
+    return result_flag
